<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lav="http://software.in2p3.fr/lavoisier/config.xsd"
                xmlns="http://software.in2p3.fr/lavoisier/config.xsd"
                xmlns:x="http://www.w3.org/TR/xpath"
                exclude-result-prefixes="lav x">
    <xsl:output method="xml" indent="yes"/>
    <xsl:include href="xpath-serializer.xsl"/>
    <xsl:variable name="MATCH_FUNCTION">match</xsl:variable>
    <xsl:variable name="EVAL_FUNCTION">eval</xsl:variable>
    <xsl:variable name="RELATIVE_FUNCTIONS">|match|local-name|name|namespace-uri|position|</xsl:variable>

    <xsl:template match="/">
        <xsl:apply-templates mode="config"/>
    </xsl:template>

    <xsl:template match="lav:processor/@match" mode="config">
        <xsl:attribute name="match">
            <xsl:choose>
                <xsl:when test="parent::lav:processor/lav:match/x:XPath">
                    <xsl:apply-templates select="parent::lav:processor/lav:match/x:XPath"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="."/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:attribute>
    </xsl:template>
    <xsl:template match="lav:processor/lav:match" mode="config"/>

    <xsl:template match="lav:processor/lav:parameter[x:XPath]" mode="config">
        <xsl:copy><xsl:copy-of select="@*[local-name()!='eval']"/>
            <xsl:apply-templates select="x:XPath"/>
        </xsl:copy>
    </xsl:template>

    <xsl:template match="x:Function">
        <xsl:choose>
            <!-- replace function with variable -->
            <xsl:when test="
                    not(
                        descendant-or-self::x:Function[@s1=$MATCH_FUNCTION or (@s1=$EVAL_FUNCTION and contains(x:PathExpr/x:FilterExpr/x:Literal/@s,'match()'))
                                                       or contains($RELATIVE_FUNCTIONS,concat('|',@s1,'|'))]
                    |   descendant::x:RelativeLocationPath[not(ancestor-or-self::x:RelativeLocationPath/preceding-sibling::x:FilterExpr)]
                    |   ancestor::x:Function
                        [not(
                            descendant-or-self::x:Function[@s1=$MATCH_FUNCTION or (@s1=$EVAL_FUNCTION and contains(x:PathExpr/x:FilterExpr/x:Literal/@s,'match()'))
                                                           or contains($RELATIVE_FUNCTIONS,concat('|',@s1,'|'))]
                        |   descendant::x:RelativeLocationPath[not(ancestor-or-self::x:RelativeLocationPath/preceding-sibling::x:FilterExpr)]
                        )]
                    )

                    and

                    not(descendant::x:RelativeLocationPath[count(current()/ancestor::x:*) > count(ancestor-or-self::x:RelativeLocationPath[preceding-sibling::x:FilterExpr][1]/ancestor::x:*)])
                ">
                <xsl:variable name="processor" select="ancestor::lav:processor"/>
                <xsl:text>$_</xsl:text>
                <xsl:value-of select="count(preceding::x:Function
                    [generate-id(ancestor::lav:processor) = generate-id($processor)]
                    [not(
                        descendant-or-self::x:Function[@s1=$MATCH_FUNCTION or (@s1=$EVAL_FUNCTION and contains(x:PathExpr/x:FilterExpr/x:Literal/@s,'match()'))
                                                       or contains($RELATIVE_FUNCTIONS,concat('|',@s1,'|'))]
                    |   descendant::x:RelativeLocationPath[not(ancestor-or-self::x:RelativeLocationPath/preceding-sibling::x:FilterExpr)]
                    |   ancestor::x:Function
                        [not(
                            descendant-or-self::x:Function[@s1=$MATCH_FUNCTION or (@s1=$EVAL_FUNCTION and contains(x:PathExpr/x:FilterExpr/x:Literal/@s,'match()'))
                                                           or contains($RELATIVE_FUNCTIONS,concat('|',@s1,'|'))]
                        |   descendant::x:RelativeLocationPath[not(ancestor-or-self::x:RelativeLocationPath/preceding-sibling::x:FilterExpr)]
                        )]
                    )]
                ) + 1"/>
            </xsl:when>

            <!-- serialize function -->
            <xsl:otherwise>
                <xsl:apply-templates select="." mode="serialize"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- default rules -->
    <xsl:template match="@*" mode="config">
        <xsl:copy-of select="."/>
    </xsl:template>
    <xsl:template match="comment()" mode="config">
        <xsl:comment><xsl:value-of select="."/></xsl:comment>
    </xsl:template>
    <xsl:template match="*" mode="config">
        <xsl:copy>
            <xsl:apply-templates select="@*|*|text()|comment()" mode="config"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>