<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lav="http://software.in2p3.fr/lavoisier/config.xsd"
                xmlns="http://software.in2p3.fr/lavoisier/config.xsd">
    <!-- This template intersects the sets contained in input_view -->
    <xsl:template match="lav:view-template[contains(@stylesheet,'IntersectionTemplate.xsl')]">
        <!-- The view that contains the sets to be intersected -->
        <xsl:variable name="input_view" select="lav:parameter[@name='input_view']/text()"/>
        <!-- An absolute XPath selecting the nodes that contain the sets to be intersected -->
        <xsl:variable name="base_path" select="lav:parameter[@name='base_path']/text()"/>
        <!-- A relative XPath selecting the sets to be intersected -->
        <xsl:variable name="set_path" select="lav:parameter[@name='set_path']/text()"/>
        <!-- A relative XPath selecting the item of the sets -->
        <xsl:variable name="item_path" select="lav:parameter[@name='item_path']/text()"/>

        <xsl:if test="not($input_view)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing required parameter: input_view</xsl:message>
        </xsl:if>
        <xsl:if test="not($base_path)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing required parameter: base_path</xsl:message>
        </xsl:if>
        <xsl:if test="not($set_path)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing required parameter: set_path</xsl:message>
        </xsl:if>
        <xsl:variable name="item_element">
            <xsl:choose>
                <xsl:when test="contains($item_path, '/text()')"><xsl:value-of select="substring-before($item_path, '/text()')"/></xsl:when>
                <xsl:when test="contains($item_path, '/@')"><xsl:value-of select="substring-before($item_path, '/@')"/></xsl:when>
                <xsl:otherwise><xsl:message terminate="yes">Parameter 'item_path' must end with attribute or text node</xsl:message></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="item_attribute">
            <xsl:choose>
                <xsl:when test="contains($item_path, '/text()')">text()</xsl:when>
                <xsl:when test="contains($item_path, '/@')">@<xsl:value-of select="substring-after($item_path, '/@')"/></xsl:when>
                <xsl:otherwise><xsl:message terminate="yes">Parameter 'item_path' must end with attribute or text node</xsl:message></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <view name="{@name}_0" post-processors="disable">
            <xsl:copy-of select="@*[not(local-name()='stylesheet' or local-name()='name' or local-name()='post-processors')]"/>
            <connector type="XMLConnector">
                <parameter name="content" eval="view('{$input_view}')"/>
            </connector>
            <processors>
                <processor type="AppendAggregateProcessor" match="{$base_path}">
                    <parameter name="function">count</parameter>
                    <parameter name="node_name">nb_keys</parameter>
                    <parameter name="node_values" eval="{$set_path}/{$item_element}[{$item_attribute}=parent_match()/{$item_attribute}]"/>
                </processor>
            </processors>
        </view>
        <view><xsl:copy-of select="@*[not(local-name()='stylesheet')] | lav:*[not(self::lav:parameter)]"/>
            <connector type="XMLConnector">
                <parameter name="content" eval="view('{$input_view}')"/>
            </connector>
            <processors>
                <processor type="AppendAggregateProcessor" match="{$base_path}">
                    <parameter name="function">count</parameter>
                    <parameter name="node_name">nb_total</parameter>
                    <parameter name="node_values" eval="{$set_path}"/>
                </processor>
                <processor type="MergeProcessor" match="{$base_path}"/>
                <processor type="RemoveProcessor" match="{$base_path}/{$set_path}"/>
                <processor type="MergeProcessor" match="{$base_path}/nb_total"/>
                <processor type="MoveProcessor" match="{$base_path}/{$item_element}">
                    <parameter name="destination_axis">following_sibling</parameter>
                    <parameter name="destination_name">nb_total</parameter>
                </processor>
                <processor type="InsertProcessor" match="{$base_path}/nb_total/{$item_element}">
                    <parameter name="nodes" eval="view_post('{@name}_0', match(), arguments())"/>
                </processor>
                <processor type="SelectAncestorProcessor" match="{$base_path}/nb_total/{$item_element}/descendant::nb_keys/text()[.=ancestor::nb_total/@nb_total]">
                    <parameter name="ancestor" eval="ancestor::{$item_element}/{$item_attribute}"/>
                </processor>
            </processors>
        </view>
    </xsl:template>
</xsl:stylesheet>