<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lav="http://software.in2p3.fr/lavoisier/config.xsd"
                xmlns="http://software.in2p3.fr/lavoisier/config.xsd"
                xmlns:e="http://software.in2p3.fr/lavoisier/entries.xsd">
    <!-- This template creates data views for non-regression testing -->
    <xsl:template match="lav:view-template[contains(@stylesheet,'NonRegressionTemplate.xsl')]">
        <xsl:variable name="test-suite" select="lav:parameter[@name='test-suite']/text()"/>
        <xsl:if test="not($test-suite)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing required parameter: test-suite</xsl:message>
        </xsl:if>
        <xsl:variable name="expected" select="lav:parameter[@name='expected']/text()"/>
        <xsl:if test="not($expected)">
            <xsl:message terminate="yes">View template '<xsl:value-of select="@stylesheet"/>' is missing required parameter: expected</xsl:message>
        </xsl:if>

        <view><xsl:copy-of select="@*[not(local-name()='stylesheet')] | lav:*[not(self::lav:parameter)]"/>
            <namespace prefix="e" uri="http://software.in2p3.fr/lavoisier/entries.xsd"/>
            <argument name="view"/>
            <connector type="DiffConnector">
                <parameter name="document1" eval="document('{$expected}')/test-suite/entries[@view=$view]/*"/>
                <parameter name="document2" eval="view('skeleton', arguments() | document('{$test-suite}')/e:test-suite/e:entries[@view=$view]/e:entry)"/>
            </connector>
        </view>
        <view name="{@name}_generate_suite"><xsl:copy-of select="lav:*[not(self::lav:parameter)]"/>
            <namespace prefix="lav" uri="http://software.in2p3.fr/lavoisier/config.xsd"/>
            <namespace prefix="e" uri="http://software.in2p3.fr/lavoisier/entries.xsd"/>
            <connector type="MemoryCacheConnector">
                <parameter name="key">!effective_configuration!</parameter>
            </connector>
            <processors>
                <processor type="SelectProcessor" match="/lav:config/lav:view
                    [not(@name='{@name}_generate_suite' or @name='{@name}_generate_expected' or @name='{@name}_all')]
                    [not(contains('|Monitoring|Configuration|Environment|Hidden|',concat('|',lav:info/lav:category,'|')))]
                    [@authenticators='_authenticators_']
                    [not(lav:argument)]
                    /@name"/>
                <processor type="MergeProcessor" match="/e:entries/e:entry"/>
                <processor type="RenameProcessor" match="/e:entries">
                    <parameter name="node_name">e:test-suite</parameter>
                </processor>
                <processor type="RenameProcessor" match="/e:test-suite/e:entry">
                    <parameter name="node_name">e:entries</parameter>
                </processor>
                <processor type="RenameProcessor" match="/e:test-suite/e:entries/@entry">
                    <parameter name="node_name">view</parameter>
                </processor>
            </processors>
        </view>
        <view name="{@name}_generate_expected"><xsl:copy-of select="lav:*[not(self::lav:parameter)]"/>
            <namespace prefix="e" uri="http://software.in2p3.fr/lavoisier/entries.xsd"/>
            <connector type="FileConnector">
                <parameter name="path"><xsl:value-of select="$test-suite"/></parameter>
            </connector>
            <processors>
                <processor type="InsertProcessor" match="/e:test-suite/e:entries[* or not(*)]">
                    <parameter name="nodes" eval="view('skeleton', * | entry('view', @view))"/>
                </processor>
                <processor type="RemoveProcessor" match="/e:test-suite/e:entries/e:entry"/>
                <processor type="ChangeNamespaceProcessor" match="/e:test-suite/e:entries"/>
                <processor type="ChangeNamespaceProcessor" match="/e:test-suite"/>
            </processors>
        </view>
        <view name="{@name}_all"><xsl:copy-of select="lav:*[not(self::lav:parameter)]"/>
            <namespace prefix="e" uri="http://software.in2p3.fr/lavoisier/entries.xsd"/>
            <connector type="FileConnector">
                <parameter name="path"><xsl:value-of select="$test-suite"/></parameter>
            </connector>
            <processors>
                <processor type="InsertProcessor" match="/e:test-suite/e:entries">
                    <parameter name="nodes" eval="view('{@name}', entry('view', @view))"/>
                </processor>
            </processors>
        </view>
    </xsl:template>
</xsl:stylesheet>