<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:cfg="http://software.in2p3.fr/lavoisier/config.xsd">
    <xsl:include href="/resource/xsl/head.xsl"/>
    <xsl:include href="/lavoisier/navbar"/>
    <xsl:output method="html" encoding="utf-8" indent="yes"/>

    <xsl:template match="/cfg:view">
        <html>
            <xsl:call-template name="head"/>
            <body>
                <xsl:call-template name="navbar"/>
                <div class="container">
                    <h2 class="page-title text-center"><xsl:value-of select="@name"/></h2>
                    <form id="form" method="get" class="form-horizontal" role="form" target="_blank">
                        <xsl:for-each select="cfg:argument">
                            <div class="form-group">
                                <label for="{@name}" class="col-sm-2 control-label"><xsl:value-of select="@name"/></label>
                                <div class="col-sm-10">
                                    <xsl:choose>
                                        <xsl:when test="contains(@pattern,'|') and not(contains(@pattern, '['))">
                                            <select name="{@name}" class="form-control">
                                                <xsl:call-template name="OPTIONS">
                                                    <xsl:with-param name="pattern" select="@pattern"/>
                                                    <xsl:with-param name="default" select="text()"/>
                                                </xsl:call-template>
                                            </select>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <input type="text" name="{@name}" value="{text()}" class="span4"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </div>
                            </div>
                        </xsl:for-each>

                        <div class="well">
                            <xsl:if test="count(cfg:authenticators/cfg:authenticator/cfg:value) > 1">
                                <div class="form-group">
                                    <label for="auth" class="col-sm-2 control-label">Authentication</label>
                                    <div class="col-sm-10">
                                        <select name="auth" id="auth" class="form-control">
                                            <option value="default">Default authentication</option>
                                            <xsl:for-each select="cfg:authenticators/cfg:authenticator/cfg:value">
                                                <option value="{text()}">
                                                    <xsl:value-of select="text()"/>
                                                </option>
                                            </xsl:for-each>
                                        </select>
                                    </div>
                                </div>
                            </xsl:if>
                            <div class="form-group">
                                <label for="accept" class="col-sm-2 control-label">Rendering</label>
                                <div class="col-sm-10">
                                    <select name="accept" id="accept" class="form-control">
                                        <xsl:variable name="selected" select="cfg:info/cfg:accept/text()"/>
                                        <option value="default">Default rendering</option>
                                        <xsl:for-each select="cfg:jmx/cfg:domain/cfg:group/cfg:mbean/cfg:attribute[@name='Extensions']/cfg:value[1][text()!='']">
                                            <option value="{text()}">
                                                <xsl:if test="text() = $selected">
                                                    <xsl:attribute name="selected">selected</xsl:attribute>
                                                </xsl:if>
                                                <xsl:value-of select="text()"/>
                                            </option>
                                        </xsl:for-each>
                                    </select>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="col-sm-2 control-label">XPath filter</label>
                                <div class="col-sm-10">
                                    <input name="xpath" id="xpath" class="form-control" type="text"
                                           placeholder="Enter XPath to filter output"/>
                                </div>
                            </div>
                            <div class="form-group">
                                <label class="col-sm-2 control-label">Range</label>
                                <div class="col-sm-10">
                                    <div class="input-group">
                                        <span class="input-group-addon">from</span>
                                        <input type="text" name="_window_start_" id="_window_start_"
                                               placeholder="Enter start of range here..." class="form-control" value="1"/>
                                        <span class="input-group-addon">to</span>
                                        <input type="text" name="_window_end_" id="_window_end_"
                                               placeholder="Enter end of range here..." class="form-control"/>
                                        <input type="hidden" name="_window_" id="_window_"/>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="form-group pull-right">
                            <input type="submit" value="Get data" onclick="get()" class="btn btn-lg"/>
                        </div>
                    </form>
                </div>
                <script language="Javascript">
function get() {
    if (document.getElementById('xpath').value != '') {
        document.getElementById('form').action='/lavoisier/<xsl:value-of select="@name"/>'+document.getElementById('xpath').value;
    } else {
        document.getElementById('form').action='/lavoisier/<xsl:value-of select="@name"/>';
    }
    if (document.getElementById('auth') &amp;&amp; document.getElementById('auth').value == 'default') {
        document.getElementById('auth').disabled=true;
    }
    if (document.getElementById('accept').value == 'default') {
        document.getElementById('accept').disabled=true;
    }
    document.getElementById('_window_start_').disabled=true;
    document.getElementById('_window_end_').disabled=true;
    if (document.getElementById('_window_end_').value != '') {
        document.getElementById('_window_').value = document.getElementById('_window_start_').value+'-'+document.getElementById('_window_end_').value;
    } else {
        document.getElementById('_window_').disabled=true;
    }
    $("#form input[type=text]").each(function() {
        if (this.value == '') {
            this.disabled = true;
        }
    })
}
                </script>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="OPTIONS">
        <xsl:param name="pattern"/>
        <xsl:param name="default"/>
        <xsl:choose>
            <xsl:when test="contains($pattern, '|')">
                <xsl:variable name="current" select="substring-before($pattern, '|')"/>
                <option value="{$current}">
                    <xsl:if test="$current = $default">
                        <xsl:attribute name="selected">selected</xsl:attribute>
                    </xsl:if>
                    <xsl:value-of select="$current"/>
                </option>
                <xsl:call-template name="OPTIONS">
                    <xsl:with-param name="pattern" select="substring-after($pattern, '|')"/>
                    <xsl:with-param name="default" select="$default"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <option value="{$pattern}">
                    <xsl:if test="$pattern = $default">
                        <xsl:attribute name="selected">selected</xsl:attribute>
                    </xsl:if>
                    <xsl:value-of select="$pattern"/>
                </option>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>