<xsl:stylesheet version="1.0"  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:date="http://exslt.org/dates-and-times"
                extension-element-prefixes="date">
    <xsl:include href="/resource/xsl/head.xsl"/>
    <xsl:include href="/lavoisier/navbar"/>
    <xsl:output method="html" encoding="utf-8" indent="yes" />

    <xsl:template match="/">
        <xsl:if test="not(/e:entries)" xmlns:e="http://software.in2p3.fr/lavoisier/entries.xsd">
            <META HTTP-EQUIV="Refresh" CONTENT="10" />
        </xsl:if>
        <html>
            <xsl:call-template name="head"/>
            <body>
                <xsl:call-template name="navbar"/>
                <div class="container">
                    <h2 class="page-title text-center">Views Status</h2>
                    <table class="table table-bordered table-striped table-sorted table-hover">
                        <tr>
                            <th>View</th>
                            <th>Status - logs</th>							
                            <th>Last build date</th>
                            <th>Last Build Duration (s)</th>
                            <th>Last Build Size (Ko)</th>
                            <th>On going build (Ko)</th>
                            <th>On going build (%)</th>
                        </tr>
                        <xsl:apply-templates/>
                    </table>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="mbean[@name='status']"/>
    <xsl:template match="mbean[@name!='status']">
        <tr>
            <td>
                <xsl:value-of select="@name"/>
            </td>
            <td>
              <xsl:choose>
                    <xsl:when test="attribute[@name='CurrentBuildStartDate']/value/text()!='null'">
                        <span class="label label-info">Currently building</span>
                    </xsl:when>
                    <xsl:when test="attribute[@name='LastException']/value/text()!='null' and attribute[@name='LastBuildDate']/value/text()!='null'">
                        <table>
                            <tr><td><span class="label label-warning">Exception raised</span></td></tr>
                            <tr><td><xsl:value-of select="attribute[@name='LastException']/value/text()"/></td></tr>
                        </table>
                    </xsl:when>
                    <xsl:when test="attribute[@name='LastException']/value/text()!='null' and attribute[@name='LastBuildDate']/value/text()='null'">
			            <table>
			                <tr><td><span class="label label-danger">Exception raised and not built yet</span></td></tr>
                            <tr><td><xsl:value-of select="attribute[@name='LastException']/value/text()"/></td></tr>
			            </table>
                    </xsl:when>
                    <xsl:when test="attribute[@name='LastBuildDate']/value/text()='null'">
                        <span class="label label-default">Not built yet</span>
                    </xsl:when>
                    <xsl:otherwise>
                         <span class="label label-success">Successfully built</span>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td style="font-size:12px">
                <xsl:if test="attribute[@name='LastBuildDate']!='null'">
                    <xsl:value-of select="attribute[@name='LastBuildDate']/value/text()"/>
                </xsl:if>
            </td>
            <td>
                <xsl:if test="attribute[@name='LastBuildTime']!='null'">
                    <xsl:value-of select="round(attribute[@name='LastBuildTime']/value/text() div 1000)"/>
                </xsl:if>
            </td>
            <td>
                <xsl:if test="attribute[@name='LastBytesSize']!='null'">
                    <xsl:value-of select="round(attribute[@name='LastBytesSize']/value/text() div 1024)"/>
                </xsl:if>
            </td>
            <td>
                <xsl:if test="attribute[@name='CurrentBytesSize']!='null'">
                    <xsl:value-of select="round(attribute[@name='CurrentBytesSize']/value/text() * 1000 div 1024) div 1000"/>
                </xsl:if>
            </td>
            <td style="font-size:12px">
                <xsl:if test="attribute[@name='CurrentBytesSize']/value/text()!='null' and attribute[@name='LastBytesSize']/value/text()!='null' ">
                    <xsl:variable name="percentage" select="round(attribute[@name='CurrentBytesSize']/value/text() div attribute[@name='LastBytesSize']/value/text() *100)"/>
                    <div class="progress">
                        <div class="bar" style="width: {$percentage}%;"/>
                    </div>
                    <div>
                        <xsl:value-of select="attribute[@name='CurrentBuildStartDate']/value/text()"/>
                    </div>
                </xsl:if>
            </td>
        </tr>
        <xsl:if test="/e:entries" xmlns:e="http://software.in2p3.fr/lavoisier/entries.xsd">
            <xsl:for-each select="attribute[@name='LastStackTrace']/value/text()">
                <tr>
                    <td colspan="6">
                        <form action="/lavoisier/send_to_dev" method="POST">
                            <div style="text-align:right;margin-bottom:5px">
                                <input type="submit" value="Send to developers" class="btn btn-warning"/>
                            </div>
                            <input name="stacktrace" type="hidden" value="{.}"/>
                            <textarea name="description" rows="5" style="width:100%">Describe the context of the problem here...</textarea>
                            <pre><xsl:apply-templates select="."/></pre>
                        </form>
                    </td>
                </tr>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>

    <xsl:template match="*[namespace-uri()='http://software.in2p3.fr/lavoisier/entries.xsd' and local-name()='entries']">
        <xsl:choose>
            <xsl:when test="count(*) > 1">
                <ul>
                    <xsl:for-each select="*">
                        <li>
                            <xsl:apply-templates select="."/>
                        </li>
                    </xsl:for-each>
                </ul>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="*[namespace-uri()='http://software.in2p3.fr/lavoisier/entries.xsd' and local-name()='entry']">
        <xsl:value-of select="text()"/>
    </xsl:template>

    <xsl:template match="*">
        <xsl:apply-templates/>
    </xsl:template>
</xsl:stylesheet>